@@ -3,6 +3,8 @@ import datetime as dt
 
 from onvif_utilities.parser import PARSERS
 from onvif_utilities.main_class import Camera
+from onvif_utilities.exceptions import ONVIFUtilitiesError
+
 UNHANDLED_TOPICS = set()
 
 class CameraEvent(Camera):
@@ -37,9 +39,14 @@ class CameraEvent(Camera):
             return event
     
     async def get_snapshot(self):
-        media_service_profile = await self.media_service.GetProfiles()        
-        image = await self.camera.get_snapshot(media_service_profile[0].token)
-        return image 
+        try:
+            media_service_profile = await self.media_service.GetProfiles()        
+            image = await self.camera.get_snapshot(media_service_profile[0].token)
+            return image 
+        except Exception as e:
+            raise ONVIFUtilitiesError(
+                str(e)
+            )
 
 if __name__=="__main__":
     async def run(): 
